@@ -549,7 +549,7 @@ class WordToken(models.Model):
             self.setStrFormants()
         return self.StrVowelF2
 
-    def getImmediateSemPred(self):
+    def getImmediatePrevSemPred(self):
         context = ['#'.join([str(x),lookupCat(str(x))]) for x in self.getPreviousContext(window=2) if lookupCat(str(x)) in ['n','v','a','r']]
         cat =lookupCat(str(self))
         if cat == 'NA':
@@ -567,6 +567,60 @@ class WordToken(models.Model):
         sp = getSemanticRelatedness('#'.join([self.WordType.Label,cat]),context)
         return sp
 
+    def getImmediateFollSemPred(self):
+        context = ['#'.join([str(x),lookupCat(str(x))]) for x in self.getFollowingContext(window=2) if lookupCat(str(x)) in ['n','v','a','r']]
+        cat =lookupCat(str(self))
+        if cat == 'NA':
+            cat = self.Category.Label
+            if 'N' in cat:
+                cat = 'n'
+            elif 'JJ' in cat:
+                cat = 'a'
+            elif 'VB' in cat:
+                cat = 'v'
+            elif 'RB' in cat:
+                cat = 'r'
+            else:
+                cat = 'NA'
+        sp = getSemanticRelatedness('#'.join([self.WordType.Label,cat]),context)
+        return sp
+
+    def getIntermedPrevSemPred(self):
+        context = ['#'.join([str(x),lookupCat(str(x))]) for x in self.getPreviousContext(window=5) if lookupCat(str(x)) in ['n','v','a','r']]
+        cat =lookupCat(str(self))
+        if cat == 'NA':
+            cat = self.Category.Label
+            if 'N' in cat:
+                cat = 'n'
+            elif 'JJ' in cat:
+                cat = 'a'
+            elif 'VB' in cat:
+                cat = 'v'
+            elif 'RB' in cat:
+                cat = 'r'
+            else:
+                cat = 'NA'
+        sp = getSemanticRelatedness('#'.join([self.WordType.Label,cat]),context)
+        return sp
+
+    def getIntermedFollSemPred(self):
+        context = ['#'.join([str(x),lookupCat(str(x))]) for x in self.getFollowingContext(window=5) if lookupCat(str(x)) in ['n','v','a','r']]
+        cat =lookupCat(str(self))
+        if cat == 'NA':
+            cat = self.Category.Label
+            if 'N' in cat:
+                cat = 'n'
+            elif 'JJ' in cat:
+                cat = 'a'
+            elif 'VB' in cat:
+                cat = 'v'
+            elif 'RB' in cat:
+                cat = 'r'
+            else:
+                cat = 'NA'
+        sp = getSemanticRelatedness('#'.join([self.WordType.Label,cat]),context)
+        return sp
+
     def getPrevSemPred(self):
         if self.PrevSemPred is not None:
             return self.PrevSemPred
@@ -1034,12 +1088,15 @@ class WordToken(models.Model):
         if form['prev_sem_pred']:
             if 'PrevSemPred' not in outline:
                 outline['PrevSemPred'] = self.getPrevSemPred()
-                #outline['ImmedSemPred'] = self.getImmediateSemPred()
-            wanted_fields.extend(['PrevSemPred'])
+                outline['ImmedPrevSemPred'] = self.getImmediatePrevSemPred()
+                outline['IntermedPrevSemPred'] = self.getIntermedPrevSemPred()
+            wanted_fields.extend(['PrevSemPred','ImmedPrevSemPred','IntermedPrevSemPred'])
         if form['foll_sem_pred']:
             if 'FollSemPred' not in outline:
                 outline['FollSemPred'] = self.getFollSemPred()
-            wanted_fields.extend(['FollSemPred'])
+                outline['ImmedFollSemPred'] = self.getImmediateFollSemPred()
+                outline['IntermedFollSemPred'] = self.getIntermedFollSemPred()
+            wanted_fields.extend(['FollSemPred','ImmedFollSemPred','IntermedFollSemPred']])
         if form['placeInDialog']:
             if 'placeInDialog' not in outline:
                 outline['placeInDialog'] = self.getDialogPlace()
